@@ -1,22 +1,9 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 /*
  * PBKDF performance check
- * Copyright (C) 2012-2018, Red Hat, Inc. All rights reserved.
- * Copyright (C) 2012-2018, Milan Broz
- * Copyright (C) 2016-2018, Ondrej Mosnacek
- *
- * This file is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This file is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this file; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * Copyright (C) 2012-2025 Red Hat, Inc. All rights reserved.
+ * Copyright (C) 2012-2025 Milan Broz
+ * Copyright (C) 2016-2020 Ondrej Mosnacek
  */
 
 #include <stdlib.h>
@@ -27,6 +14,10 @@
 #include <sys/resource.h>
 #include "crypto_backend.h"
 
+#ifndef CLOCK_MONOTONIC_RAW
+#define CLOCK_MONOTONIC_RAW CLOCK_MONOTONIC
+#endif
+
 #define BENCH_MIN_MS 250
 #define BENCH_MIN_MS_FAST 10
 #define BENCH_PERCENT_ATLEAST 95
@@ -44,14 +35,16 @@ int crypt_pbkdf_get_limits(const char *kdf, struct crypt_pbkdf_limits *limits)
 		limits->min_iterations = 1000; /* recommendation in NIST SP 800-132 */
 		limits->max_iterations = UINT32_MAX;
 		limits->min_memory     = 0; /* N/A */
+		limits->min_bench_memory=0; /* N/A */
 		limits->max_memory     = 0; /* N/A */
 		limits->min_parallel   = 0; /* N/A */
 		limits->max_parallel   = 0; /* N/A */
 		return 0;
-	} else if (!strncmp(kdf, "argon2", 6)) {
+	} else if (!strcmp(kdf, "argon2i") || !strcmp(kdf, "argon2id")) {
 		limits->min_iterations = 4;
 		limits->max_iterations = UINT32_MAX;
-		limits->min_memory     = 32;
+		limits->min_memory     = 32;      /* hard limit */
+		limits->min_bench_memory=64*1024; /* 64 MiB minimum for benchmark */
 		limits->max_memory     = 4*1024*1024; /* 4GiB */
 		limits->min_parallel   = 1;
 		limits->max_parallel   = 4;
@@ -70,7 +63,7 @@ static long time_ms(struct rusage *start, struct rusage *end)
 		count_kernel_time = 1;
 
 	/*
-	 * FIXME: if there is no self usage info, count system time.
+	 * If there is no self usage info, count system time.
 	 * This seem like getrusage() bug in some hypervisors...
 	 */
 	if (!end->ru_utime.tv_sec && !start->ru_utime.tv_sec &&
@@ -151,7 +144,7 @@ static int next_argon2_params(uint32_t *t_cost, uint32_t *m_cost,
 	old_t_cost = *t_cost;
 	old_m_cost = *m_cost;
 
-	if (ms > target_ms) {
+	if ((uint32_t)ms > target_ms) {
 		/* decreasing, first try to lower t_cost, then m_cost */
 		num = (uint64_t)*t_cost * (uint64_t)target_ms;
 		denom = (uint64_t)ms;
@@ -202,7 +195,7 @@ static int next_argon2_params(uint32_t *t_cost, uint32_t *m_cost,
 static int crypt_argon2_check(const char *kdf, const char *password,
 			      size_t password_length, const char *salt,
 			      size_t salt_length, size_t key_length,
-			      uint32_t min_t_cost, uint32_t max_m_cost,
+			      uint32_t min_t_cost, uint32_t min_m_cost, uint32_t max_m_cost,
 			      uint32_t parallel, uint32_t target_ms,
 			      uint32_t *out_t_cost, uint32_t *out_m_cost,
 			      int (*progress)(uint32_t time_ms, void *usrptr),
@@ -210,7 +203,7 @@ static int crypt_argon2_check(const char *kdf, const char *password,
 {
 	int r = 0;
 	char *key = NULL;
-	uint32_t t_cost, m_cost, min_m_cost = 8 * parallel;
+	uint32_t t_cost, m_cost;
 	long ms;
 	long ms_atleast = (long)target_ms * BENCH_PERCENT_ATLEAST / 100;
 	long ms_atmost = (long)target_ms * BENCH_PERCENT_ATMOST / 100;
@@ -218,6 +211,9 @@ static int crypt_argon2_check(const char *kdf, const char *password,
 	if (key_length <= 0 || target_ms <= 0)
 		return -EINVAL;
 
+	if (min_m_cost < (parallel * 8))
+		min_m_cost = parallel * 8;
+
 	if (max_m_cost < min_m_cost)
 		return -EINVAL;
 
@@ -304,6 +300,7 @@ static int crypt_argon2_check(const char *kdf, const char *password,
 	} while (ms < ms_atleast || ms > ms_atmost);
 out:
 	if (key) {
+		/* Key can be derived from a real provided password */
 		crypt_backend_memzero(key, key_length);
 		free(key);
 	}
@@ -354,8 +351,10 @@ static int crypt_pbkdf_check(const char *kdf, const char *hash,
 		ms = time_ms(&rstart, &rend);
 		if (ms) {
 			PBKDF2_temp = (double)iterations * target_ms / ms;
-			if (PBKDF2_temp > UINT32_MAX)
-				return -EINVAL;
+			if (PBKDF2_temp > UINT32_MAX) {
+				r = -EINVAL;
+				goto out;
+			}
 			*iter_secs = (uint32_t)PBKDF2_temp;
 		}
 
@@ -383,6 +382,7 @@ static int crypt_pbkdf_check(const char *kdf, const char *hash,
 	}
 out:
 	if (key) {
+		/* Key can be derived from a real provided password */
 		crypt_backend_memzero(key, key_length);
 		free(key);
 	}
@@ -399,6 +399,7 @@ int crypt_pbkdf_perf(const char *kdf, const char *hash,
 {
 	struct crypt_pbkdf_limits pbkdf_limits;
 	int r = -EINVAL;
+	uint32_t min_memory;
 
 	if (!kdf || !iterations_out || !memory_out)
 		return -EINVAL;
@@ -407,6 +408,13 @@ int crypt_pbkdf_perf(const char *kdf, const char *hash,
 	if (r < 0)
 		return r;
 
+	if (parallel_threads > pbkdf_limits.max_parallel)
+		return -EINVAL;
+
+	min_memory = pbkdf_limits.min_bench_memory;
+	if (min_memory > max_memory_kb)
+		min_memory = max_memory_kb;
+
 	*memory_out = 0;
 	*iterations_out = 0;
 
@@ -418,7 +426,9 @@ int crypt_pbkdf_perf(const char *kdf, const char *hash,
 	else if (!strncmp(kdf, "argon2", 6))
 		r = crypt_argon2_check(kdf, password, password_size,
 				       salt, salt_size, volume_key_size,
-				       pbkdf_limits.min_iterations, max_memory_kb,
+				       pbkdf_limits.min_iterations,
+				       min_memory,
+				       max_memory_kb,
 				       parallel_threads, time_ms, iterations_out,
 				       memory_out, progress, usrptr);
 	return r;
