@@ -14,7 +14,7 @@
 # $1 full target dir
 # $2 full source luks2 image
 
-function generate()
+generate()
 {
 	read -r json_str_orig < $TMPDIR/json0
 	arr_len=$(jq -c -M '.digests."0".segments | length' $TMPDIR/json0)
@@ -29,7 +29,7 @@ function generate()
 	lib_mangle_json_hdr0_kill_hdr1
 }
 
-function check()
+check()
 {
 	lib_hdr1_killed || exit 2
 	lib_hdr0_checksum || exit 2
